import {
  GdsElement
} from "./chunk.TMEWQZER.js";
import {
  gdsCustomElement,
  html
} from "./chunk.QK3R23GV.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "./chunk.SEHSDSX2.js";

// libs/core/src/primitives/form-control-header/form-control-header.ts
import { localized, msg } from "@lit/localize";
import { property, query, state } from "lit/decorators.js";
import { when } from "lit/directives/when.js";

// libs/core/src/primitives/form-control-header/form-control-header.styles.ts
import { css } from "lit";
var styles = css`
  @layer base, reset, transitional-styles;
  @layer base {
    #label-row {
      display: flex;
      justify-content: space-between;
      align-items: center;
      line-height: var(--gds-text-line-height-detail-m);

      & > div {
        display: flex;
        flex-direction: column;
      }
    }

    ::slotted(label) {
      font-weight: var(--gds-text-weight-book);
    }

    :host(.size-small) {
      & slot[name='supporting-text'],
      & ::slotted(label) {
        font-size: var(--gds-text-size-detail-s);
        line-height: var(--gds-text-line-height-detail-s);
      }
    }

    #extended-supporting-text {
      opacity: 1;
      transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
      transition-duration: 368ms;
      transition-property: all;
      font-size: var(--gds-text-size-body-s);
      line-height: var(--gds-text-line-height-body-s);
      border-radius: var(--gds-space-xs);
      background-color: var(--gds-color-l3-background-secondary);
      color: var(--gds-color-l3-content-tertiary);
      max-height: var(--_max-height);

      &[aria-hidden='false'] {
        margin: var(--gds-space-2xs) 0 0 0;
        padding: var(--gds-space-s) var(--gds-space-m);
      }

      &[aria-hidden='true'] {
        max-height: 0;
        opacity: 0;
        translate: 0 2px;
        padding: 0 var(--gds-space-m);
        margin: 0;
        overflow: hidden;
      }
    }
  }
`;

// libs/core/src/primitives/form-control-header/form-control-header.ts
var _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn, _renderExtSupTxtButton, _handleExtSupTxtBtnClick, _renderExtSupTxt, renderExtSupTxt_fn;
var GdsFormControlHeader = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleExtSupTxtSlotChange);
    __privateAdd(this, _renderExtSupTxt);
    this.showExtendedSupportingText = false;
    this._hasExtendedSupportingText = false;
    __privateAdd(this, _renderExtSupTxtButton, () => {
      return html`
      <gds-button
        size="small"
        rank="tertiary"
        label="${msg("Show more information")}"
        gds-aria-expanded="${this.showExtendedSupportingText}"
        @click=${__privateGet(this, _handleExtSupTxtBtnClick)}
      >
        <gds-icon-circle-info ?solid=${this.showExtendedSupportingText} />
      </gds-button>
    `;
    });
    __privateAdd(this, _handleExtSupTxtBtnClick, () => {
      var _a;
      this.showExtendedSupportingText = !this.showExtendedSupportingText;
      (_a = this._extendedSupportingText) == null ? void 0 : _a.style.setProperty(
        "--_max-height",
        this.showExtendedSupportingText ? `${this._extendedSupportingText.scrollHeight}px` : "0"
      );
      this.dispatchEvent(
        new CustomEvent("gds-ui-state", {
          bubbles: true,
          composed: true,
          detail: this.showExtendedSupportingText
        })
      );
    });
  }
  render() {
    return html`
      <div id="label-row">
        <div>
          <slot name="label"></slot>
          <slot name="supporting-text"></slot>
        </div>
        ${when(this._hasExtendedSupportingText, __privateGet(this, _renderExtSupTxtButton))}
      </div>

      ${__privateMethod(this, _renderExtSupTxt, renderExtSupTxt_fn).call(this)}
    `;
  }
};
_handleExtSupTxtSlotChange = new WeakSet();
handleExtSupTxtSlotChange_fn = function(e) {
  this._hasExtendedSupportingText = e.target.assignedElements({ flatten: true }).length > 0;
};
_renderExtSupTxtButton = new WeakMap();
_handleExtSupTxtBtnClick = new WeakMap();
_renderExtSupTxt = new WeakSet();
renderExtSupTxt_fn = function() {
  return html`
      <div
        id="extended-supporting-text"
        aria-hidden="${this.showExtendedSupportingText ? "false" : "true"}"
        ?inert=${!this.showExtendedSupportingText}
      >
        <slot
          name="extended-supporting-text"
          @slotchange=${__privateMethod(this, _handleExtSupTxtSlotChange, handleExtSupTxtSlotChange_fn)}
        ></slot>
      </div>
    `;
};
GdsFormControlHeader.styles = [styles];
__decorateClass([
  property({
    type: Boolean,
    reflect: true
  })
], GdsFormControlHeader.prototype, "showExtendedSupportingText", 2);
__decorateClass([
  state()
], GdsFormControlHeader.prototype, "_hasExtendedSupportingText", 2);
__decorateClass([
  query("#extended-supporting-text")
], GdsFormControlHeader.prototype, "_extendedSupportingText", 2);
GdsFormControlHeader = __decorateClass([
  gdsCustomElement("gds-form-control-header"),
  localized()
], GdsFormControlHeader);

export {
  GdsFormControlHeader
};
