import {
  lockBodyScrolling,
  registerGlobalScrollLockStyles,
  unlockBodyScrolling
} from "./chunk.KAP7LDUQ.js";
import {
  watch
} from "./chunk.TYGMNHNO.js";
import {
  GdsElement
} from "./chunk.TMEWQZER.js";
import {
  gdsCustomElement,
  html
} from "./chunk.QK3R23GV.js";
import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "./chunk.SEHSDSX2.js";

// libs/core/src/components/dialog/dialog.ts
import { localized, msg } from "@lit/localize";
import { property, query } from "lit/decorators.js";
import { when } from "lit/directives/when.js";

// libs/core/src/components/dialog/dialog.styles.ts
import { css } from "lit";
var styles = css`
  @layer base, reset, transitional-styles;
  @layer base {
    :host {
      display: contents;
    }

    dialog {
      transition: 0.3s;
      background: transparent;
      padding: 0;
      border-width: 0;
      overflow: visible;
      max-width: 100vw;
      max-height: 100vh;
      display: flex;

      @starting-style {
        opacity: 0;
        transform: translateY(-16px);
        &::backdrop {
          opacity: 0;
          backdrop-filter: blur(0);
        }
      }

      &::backdrop {
        transition: 0.3s;
        background: rgba(100, 100, 100, 0.3);
        backdrop-filter: blur(3px);
      }
    }

    dialog > * {
      flex-grow: 1;
    }

    dialog.default {
      width: 400px;
      max-height: 400px;
    }

    dialog.slide-out {
      width: 600px;
      height: 100vh;
      inset: 0 0 0 auto;
      @starting-style {
        transform: translateX(96px);
      }
    }

    .card {
      flex-direction: column;
    }

    slot[name='footer'] > *,
    slot[name='footer']::slotted(*) {
      flex: 1;
    }

    h2 {
      margin: 0;
      padding: 0;
      font-size: 1.5rem;
      font-weight: 450;
    }
  }
`;

// libs/core/src/components/dialog/dialog.ts
registerGlobalScrollLockStyles();
var _returnValue, _handleNativeClose, _dispatchCloseEvent, _dispatchShowEvent, _dispatchUiStateEvent, _handleTriggerSlotChange, handleTriggerSlotChange_fn, _handleTriggerClick;
var GdsDialog = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleTriggerSlotChange);
    this.open = false;
    this.variant = "default";
    __privateAdd(this, _returnValue, void 0);
    __privateAdd(this, _handleNativeClose, (e) => {
      const dialog = e.target;
      const returnValue = dialog.returnValue;
      this.close(returnValue || "native-close");
      if (returnValue !== "prop-change")
        __privateGet(this, _dispatchCloseEvent).call(this, returnValue);
    });
    __privateAdd(this, _dispatchCloseEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-close", {
          detail: reason,
          bubbles: false,
          composed: false
        })
      );
      __privateGet(this, _dispatchUiStateEvent).call(this, reason);
    });
    __privateAdd(this, _dispatchShowEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-show", {
          detail: reason,
          bubbles: false,
          composed: false
        })
      );
      __privateGet(this, _dispatchUiStateEvent).call(this, reason);
    });
    __privateAdd(this, _dispatchUiStateEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-ui-state", {
          detail: { reason, open: this.open },
          bubbles: false,
          composed: false
        })
      );
    });
    __privateAdd(this, _handleTriggerClick, (e) => {
      this.show("slotted-trigger");
    });
  }
  /**
   * Opens the dialog.
   */
  show(reason) {
    this.open = true;
    reason && __privateGet(this, _dispatchShowEvent).call(this, reason);
  }
  /**
   * Closes the dialog.
   * @param returnValue - The value to return when the dialog is closed.
   */
  close(reason) {
    __privateSet(this, _returnValue, reason);
    this.open = false;
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    unlockBodyScrolling(this);
  }
  render() {
    return html`<slot
        name="trigger"
        @slotchange=${__privateMethod(this, _handleTriggerSlotChange, handleTriggerSlotChange_fn)}
      ></slot>
      ${when(
      this.open,
      () => html`<dialog
            @close=${__privateGet(this, _handleNativeClose)}
            class=${this.variant}
            aria-describedby="heading"
          >
            <gds-card
              class="card"
              display="flex"
              variant="secondary"
              shadow="xl"
              padding="s"
              border-radius=${this.variant === "default" ? "s" : "0"}
            >
              <gds-flex
                justify-content="space-between"
                border="0 0 4xs/primary 0"
                margin="0 -s"
                padding="0 s s"
                background-color="secondary"
              >
                <h2 id="heading">${this.heading}</h2>
                <gds-button
                  id="close-btn"
                  rank="secondary"
                  size="small"
                  label=${msg("Close")}
                  @click=${() => this.close("btn-close")}
                  ><gds-icon-cross-large></gds-icon-cross-large
                ></gds-button>
              </gds-flex>
              <gds-container
                id="content"
                padding="m 0"
                overflow="auto"
                flex="1"
              >
                <slot></slot>
              </gds-container>
              <gds-flex
                class="footer"
                justify-content="center"
                gap="s"
                padding="s 0 0 0"
              >
                <slot name="footer">
                  <gds-button
                    value="cancel"
                    @click=${() => this.close("btn-cancel")}
                    rank="secondary"
                    >${msg("Cancel")}</gds-button
                  >
                  <gds-button value="ok" @click=${() => this.close("btn-ok")}
                    >Ok</gds-button
                  >
                </slot>
              </gds-flex>
            </gds-card>
          </dialog>`
    )}`;
  }
  _handleOpenChange() {
    var _a;
    if (this.open) {
      __privateSet(this, _returnValue, void 0);
      this.updateComplete.then(() => {
        var _a2;
        (_a2 = this._elDialog) == null ? void 0 : _a2.showModal();
        lockBodyScrolling(this);
      });
    } else {
      __privateSet(this, _returnValue, __privateGet(this, _returnValue) || "prop-change");
      (_a = this._elDialog) == null ? void 0 : _a.close(__privateGet(this, _returnValue));
      unlockBodyScrolling(this);
      this.requestUpdate("open");
    }
  }
};
_returnValue = new WeakMap();
_handleNativeClose = new WeakMap();
_dispatchCloseEvent = new WeakMap();
_dispatchShowEvent = new WeakMap();
_dispatchUiStateEvent = new WeakMap();
_handleTriggerSlotChange = new WeakSet();
handleTriggerSlotChange_fn = function() {
  if (this._elTriggerSlot && this._elTriggerSlot.assignedElements()[0]) {
    const trigger = this._elTriggerSlot.assignedElements()[0];
    trigger == null ? void 0 : trigger.addEventListener("click", __privateGet(this, _handleTriggerClick));
    trigger == null ? void 0 : trigger.setAttribute("aria-haspopup", "dialog");
  }
};
_handleTriggerClick = new WeakMap();
GdsDialog.styles = [styles];
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsDialog.prototype, "open", 2);
__decorateClass([
  property()
], GdsDialog.prototype, "heading", 2);
__decorateClass([
  property()
], GdsDialog.prototype, "variant", 2);
__decorateClass([
  query("dialog")
], GdsDialog.prototype, "_elDialog", 2);
__decorateClass([
  query('slot[name="trigger"]')
], GdsDialog.prototype, "_elTriggerSlot", 2);
__decorateClass([
  watch("open")
], GdsDialog.prototype, "_handleOpenChange", 1);
GdsDialog = __decorateClass([
  gdsCustomElement("gds-dialog"),
  localized()
], GdsDialog);

export {
  GdsDialog
};
