import { GdsElement } from '../../gds-element';
/**
 * @element gds-divider
 *
 * The `gds-divider`  is a custom element that provides a flexible divider system.
 * It can be used to create a divider with different styles and configurations.
 * The divider can be customized with different properties like color and size
 *
 * @status beta
 *
 */
export declare class GdsDivider extends GdsElement {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The level of the divider is used to resolve the color tokens from the corresponding level.
     * Check the [Color System documentation page](./?path=/docs/style-colors--docs) for more information.
     *
     * Default value for `gds-divider` is set to `2`.
     *
     * @property level
     *
     * */
    level: string;
    /**
     * Controls the color property of the divider.
     * Supports all the color tokens from the design system.
     *
     * You can apply color like this:
     *
     * ```html
     * <gds-divider color="primary"></gds-divider>
     * ```
     *
     * The above example will apply the color style of base400.
     *
     */
    color?: string;
    /**
     * Controls the size property of the divider.
     * Supports all the space tokens from the design system.
     *
     * You can apply size like this:
     *
     * ```html
     * <gds-divider size="2xl"></gds-divider>
     * ```
     *
     * The above example will apply the size style of 2xl.
     *
     */
    size?: string;
    /**
     * Controls the opacity property of the divider.
     * Supports all the opacity tokens from the design system.
     *
     * You can apply opacity like this:
     *
     * ```html
     * <gds-divider opacity="0.2"></gds-divider>
     * ```
     * The above example will apply the opacity style of base400.
     *
     */
    opacity?: string;
    render(): any;
}
