import { GdsContainer } from '../container';
/**
 * The `gds-flex` component is a flex element that can be used to wrap other components and control the layout of its children.
 *
 * It can be used in combination with other elements like `gds-grid`, `gds-card`, `gds-img`, `gds-text` etc.
 *
 * @element gds-flex
 * @status beta
 *
 */
export declare class GdsFlex extends GdsContainer {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the gap property of the flex.
     * Supports all space tokens as value.
     *
     * You can apply gap in each column and row like this:
     * ```html
     * <gds-flex gap="m s"></gds-flex>
     * ```
     *
     * The `gap` can be applied on `flex` using shorthand like gap="m s"
     *
     * Gap also support breakpoint syntax like this:
     * ```html
     * <gds-flex gap="xs{s} m{m} l{xl}"></gds-flex>
     * ```
     * The above example will apply the gap style of `xs` for `small` devices, `m` for `medium` devices, and `xl` for large devices.
     *
     */
    gap?: string;
    /**
     * Controls the `flex` property of the flex.
     * Supports all valid CSS flex property values.
     */
    flex?: string;
    /**
     * Controls the `align-self` property of the flex.
     * Supports all valid CSS align-self values.
     */
    'align-self'?: string;
    /**
     * Controls the `align-items` property of the flex.
     * Supports all valid CSS align-items values.
     */
    'align-items'?: string;
    /**
     * Controls the `align-content` property of the flex.
     * Supports all valid CSS align-content values.
     */
    'align-content'?: string;
    /**
     * Controls the `justify-content` property of the flex.
     * Supports all valid CSS justify-content values.
     */
    'justify-content'?: string;
    /**
     * Controls the `place-content` property of the flex.
     * Supports all valid CSS place-content values.
     */
    'place-content'?: string;
    /**
     * Controls the `justify-items` property of the flex.
     * Supports all valid CSS justify-items values.
     */
    'justify-items'?: string;
    /**
     * Controls the `justify-self` property of the flex.
     * Supports all valid CSS justify-self values.
     */
    'justify-self'?: string;
    /**
     * Controls the flex-direction property of the flex.
     * Supports all valid CSS flex-direction values.
     */
    'flex-direction'?: string;
    /**
     * Controls the flex-wrap property of the flex.
     * Supports all valid CSS flex-wrap values.
     */
    'flex-wrap'?: string;
    connectedCallback(): void;
    render(): any;
}
