import { GdsElement } from '../../gds-element';
export interface GdsValidator {
    /**
     * Validate the form control element. Should return the validity state and an optional validation message.
     */
    validate(element: GdsFormControlElement): [ValidityState, string] | undefined;
}
/**
 * Abstract base class for Green Core form controls.
 *
 * This class sets up the form-associated custom element API, along with some
 * other common form control functionality that all Green Core form controls share.
 *
 * @internal
 */
export declare abstract class GdsFormControlElement<ValueT = any> extends GdsElement implements Partial<Omit<HTMLInputElement, 'value'>> {
    #private;
    static formAssociated: boolean;
    constructor();
    /**
     * A validator that can be used to validate the form control and set an error message.
     */
    validator?: GdsValidator;
    required: boolean;
    /**
     * This can be used to manually control the error message that will be displayed
     * when the control is invalid.
     */
    errorMessage: string;
    /**
     * Validation state of the form control. Setting this to true triggers the invalid state of the control.
     *
     * @attr aria-invalid
     */
    set invalid(value: boolean);
    get invalid(): boolean;
    /**
     * The label of the form control.
     */
    label: string;
    /**
     * Get or set the value of the form control.
     */
    protected _internalValue?: ValueT;
    get value(): ValueT | undefined;
    set value(value: ValueT | undefined);
    name: string;
    /**
     * If the input is Disabled
     */
    disabled: boolean;
    /**
     * The form element that the form control is associated with.
     */
    get form(): HTMLFormElement | null;
    get validity(): ValidityState;
    get validationMessage(): string;
    get willValidate(): boolean;
    checkValidity(): boolean;
    reportValidity(): boolean;
    private __handleValueChange;
    formResetCallback(): void;
    formAssociatedCallback(form?: HTMLFormElement): void;
    protected _handleFormSubmit(e: Event): void;
    focus(options?: FocusOptions | undefined): void;
    /**
     * This should return a reference to the HTML element that will recive the focus when the form control is invalid.
     */
    protected abstract _getValidityAnchor(): HTMLElement;
}
