import { GdsFormControlElement } from '../form/form-control';
import '../../primitives/form-control-header';
import '../../primitives/form-control-footer';
import '../../primitives/field-base';
import '../icon/icons/cross-large';
import '../flex';
import '../button';
import type { GdsButton } from '../button';
/**
 * @summary A custom input element that can be used in forms.
 * @status beta
 *
 * @element gds-input
 *.
 * @slot lead - Accepts `gds-icon-[ICON_NAME]`. Use this to place an icon in the start of the field.
 * @slot trail - Accepts `gds-badge`. Use this to place a badge in the field, for displaying currency for example.
 * @slot extended-supporting-text - A longer supporting text can be placed here. It will be
 *       displayed in a panel when the user clicks the info button.
 * @event gds-input-cleared - Fired when the clear button is clicked.
 */
export declare class GdsInput extends GdsFormControlElement<string> {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The supporting text displayed between the label and the field.
     * This text provides additional context or information to the user.
     */
    supportingText: string;
    /**
     * Whether the supporting text should be displayed or not.
     */
    showExtendedSupportingText: boolean;
    /**
     * Whether the field should be clearable or not. Clearable fields will display a clear button when
     * the field has a value.
     */
    clearable: boolean;
    /**
     * The maximum number of characters allowed in the field.
     */
    maxlength: number;
    /**
     * The variant of the input field. The default variant displays a label, supporting text, and
     * extended supporting text. The floating-label variant only displays the field itself and the
     * supporting text below.
     *
     * The floating-label variant should only be used in specific cases, for example when the input field
     * is placed inside a table cell or in a space-constrained layout.
     *
     * A typical form should use the default variant.
     */
    variant: 'default' | 'floating-label';
    /**
     * Controls the font-size of texts and height of the field.
     */
    size: 'large' | 'small';
    private elInputAsync;
    private elInput;
    /**
     * A reference to the clear button element. Returns null if there is no clear button.
     * Intended for use in integration tests.
     */
    test_getClearButton(): GdsButton<any> | null | undefined;
    /**
     * A reference to the field element. This does not refer to the input element itself,
     * but the wrapper that makes up the visual field.
     * Intended for use in integration tests.
     */
    test_getFieldElement(): Element | null | undefined;
    constructor();
    render(): any;
    _getValidityAnchor(): HTMLInputElement;
}
