import { GdsElement } from '../../gds-element';
/**
 * @element gds-link
 * @status beta
 *
 * @slot main - Content to be displayed as the link string.
 * @slot lead - An optional slot that allows a `gds-icon` element to be placed before the label.
 * @slot trail - An optional slot that allows a `gds-icon` element to be placed after the label.
 *
 * @event click - Fired when the link is clicked.
 *
 */
export declare class GdsLink extends GdsElement {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    static shadowRootOptions: ShadowRootInit;
    /**
     * When set, the underlying button will be rendered as an anchor element.
     */
    href: string;
    /**
     * Where to display the linked URL. Only used when href is present.
     */
    target?: '_self' | '_blank' | '_parent' | '_top';
    /**
     * The relationship of the linked URL as space-separated link types. Only used when href is present. Defaults to "noreferrer noopener" for security reasons when target is set.
     */
    rel?: string;
    /**
     * Causes the browser to treat the linked URL as a download. Can be used with or without a filename value. Only used when href is present.
     */
    download?: string;
    /**
     * Controls the text-decoration property of the link.
     * Supports all valid CSS text-decoration values.
     *
     * Setting `text-decoration` on hover you can do it like this:
     * ```html
     * <gds-link text-decoration="hover:underline">Underline on Hover</gds-link>
     * ```
     * @property text-decoration
     */
    'text-decoration'?: string;
    constructor();
    render(): import("lit-html").TemplateResult;
}
