import { LitElement, ReactiveController } from 'lit';
/**
 * Components that use `ListboxKbNavController` needs to implement this interface.
 */
export interface ListboxKbNavigation extends LitElement {
    /**
     * Should return a list of navigable HTMLElements.
     */
    navigableItems: HTMLElement[];
}
/**
 * Controller that handles keyboard navigation for `ListboxKbNavigation` compatible components.
 * @internal
 *
 * The purpose of this controller is to provide a reusable implementation of the keyboard
 * interaction patterns decribed here:
 * https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/listbox_role
 */
export declare class ListboxKbNavController implements ReactiveController {
    #private;
    host: ListboxKbNavigation;
    constructor(host: ListboxKbNavigation);
    hostConnected(): void;
    hostDisconnected(): void;
}
